@@ -4,7 +4,12 @@ use Any::Moose;
 has url      => ( is => "rw", isa => "Str", required => 1 );
 has user     => ( is => "rw", isa => "Str", required => 1 );
 has password => ( is => "rw", isa => "Str", required => 1 );
-has directory => (is => "rw", isa => "Net::Redmine");
+
+has _live_ticket_objects => (
+    is => "rw",
+    isa => "HashRef",
+    default => sub { {} }
+);
 
 has mechanize => (
     is => "rw",
